<TS language="zh_TW" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>產生一個新位址</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新增</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>複製目前選擇的位址到系統剪貼簿</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>把目前選擇的位址從列表中刪掉</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>刪掉</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>複製標記</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編輯</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>標記</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>位址</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(無標記)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>密碼對話視窗</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>請輸入密碼</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>新密碼</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>重複新密碼</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>輸入錢包的新密碼。&lt;br/&gt;密碼請用&lt;b&gt;10 個以上的隨機字元&lt;/b&gt;，或是&lt;b&gt;8 個以上的字詞&lt;/b&gt;。</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>加密錢包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>這個動作需要你的錢包密碼來解鎖錢包。</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>解鎖錢包</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>改變密碼</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>確認錢包加密</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>你確定要把錢包加密嗎？</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>錢包已加密</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>重要: 請改用新產生有加密的錢包檔，來取代舊錢包檔的備份。為了安全性的理由，當你開始使用新的有加密的錢包後，舊錢包檔的備份就不能再使用了。</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>錢包加密失敗</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>因為內部錯誤導致錢包加密失敗。你的錢包還是沒加密。</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>提供的密碼不一樣。</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>錢包解鎖失敗</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>輸入要用來解密錢包的密碼不對。</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>錢包密碼改成功了。</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>警告: 大寫字母鎖定作用中！</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>錢包</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>總覽</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>顯示錢包一般總覽</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>付款</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>收款</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>瀏覽交易紀錄</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>結束</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>結束應用程式</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>選項...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>顯示或隱藏</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>加密錢包...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>改變密碼...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>改變錢包加密用的密碼</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>簽署訊息...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>驗證訊息...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>除錯視窗</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>開啓除錯和診斷主控台</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>檔案</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>說明</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>最新狀態</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>正在趕進度...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>付款交易</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>收款交易</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>錢包&lt;b&gt;已加密&lt;/b&gt;並且&lt;b&gt;上鎖中&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>數目:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>位元組數:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>金額:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>手續費:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>計費後金額:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>找零金額:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>金額</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>確認次數</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>已確認</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>複製位址</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>複製標記</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>複製金額</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>複製交易識別碼</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>複製數目</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>複製手續費</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>複製計費後金額</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>複製位元組數</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>複製找零金額</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(無標記)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>找零前是 %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(找零)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>編輯位址</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>標記</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>位址</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>造新的收款位址</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>造新的付款位址</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>編輯收款位址</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>編輯付款位址</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>輸入的位址 %1 在位址簿中已經有了。</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>沒辦法把錢包解鎖。</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>產生新的密鑰失敗了。</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>主要</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>用 &amp;UPnP 設定通訊埠對應</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>埠號:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>代理伺服器的通訊埠(像是 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>視窗</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>視窗縮到最小後只在通知區顯示圖示。</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>縮到最小到通知區而不是工作列</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>關閉時縮到最小</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>顯示</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>使用界面語言:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>金額顯示單位:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>選擇操作界面和付款時，預設顯示金額的細分單位。</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>好</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>default</source>
        <translation>預設值</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>提供的代理伺服器位址無效。</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>表單</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>可用金額:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>目前可用餘額</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>未成熟金額:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>總金額:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>目前全部餘額</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>客戶端軟體版本</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>資訊</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>啓動時間</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>連線數</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>區塊鏈</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>目前區塊數</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>最近區塊時間</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>開啓</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>清掉</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>主控台</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>網路流量</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>總計</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>來:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>去:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>除錯紀錄檔</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>清主控台</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>請用上下游標鍵來瀏覽先前指令的紀錄，並用 &lt;b&gt;Ctrl-L&lt;/b&gt; 來清畫面。</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>請打 &lt;b&gt;help&lt;/b&gt; 來看可用指令的簡介。</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 B (位元組)</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB (千位元組)</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 MB (百萬位元組)</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GB (十億位元組)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>付款</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>輸入...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>自動選擇</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>累計金額不足！</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>數目:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>位元組數:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>金額:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>手續費:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>計費後金額:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>一次付給多個收款人</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>增加收款人</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>全部清掉</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>確認付款動作</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>付款</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>複製數目</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>複製金額</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>複製手續費</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>複製計費後金額</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>複製位元組數</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>複製找零金額</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>確認付款金額</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>付款金額必須大於零。</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>金額超過餘額了。</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>包含 %1 的交易手續費後，總金額超過你的餘額了。</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(無標記)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>金額:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>付給:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>訊息:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>標記:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>貼上剪貼簿裡的位址</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>請輸入這個位址的標記來把它加進位址簿中</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>簽章 - 簽署或驗證訊息</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>簽署訊息</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>貼上剪貼簿裡的位址</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>請在這裡輸入你想簽署的訊息</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>複製目前的簽章到系統剪貼簿</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>簽署訊息</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>重設所有訊息簽署欄位</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>全部清掉</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>驗證訊息</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>重設所有訊息驗證欄位</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>請按一下「簽署訊息」來產生簽章</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>輸入的位址無效。</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>請檢查位址是否正確後再試一次。</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>輸入的位址沒有對應到你的任何密鑰。</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>錢包解鎖已取消。</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>沒有對應輸入位址的密鑰。</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>訊息簽署失敗。</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>訊息簽署好了。</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>沒辦法把這個簽章解碼。</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>請檢查簽章是否正確後再試一次。</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>這個簽章跟訊息的數位摘要不符。</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>訊息驗證失敗。</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>訊息驗證沒錯。</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>到 %1 前可修改</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1 次/離線中</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1 次/未確認</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>確認 %1 次</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>，還沒成功公告出去</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>來源</translation>
    </message>
    <message>
        <source>From</source>
        <translation>來源</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>To</source>
        <translation>目的</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>自己的位址</translation>
    </message>
    <message>
        <source>label</source>
        <translation>標記</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>入帳</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>不被接受</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>出帳</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>交易手續費</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>淨額</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>附註</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>金額</translation>
    </message>
    <message>
        <source>true</source>
        <translation>是</translation>
    </message>
    <message>
        <source>false</source>
        <translation>否</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>這個版面顯示這次交易的詳細說明</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>種類</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>到 %1 前可修改</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>離線中</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>未確認</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>已確認(%1 次)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>有衝突</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>生產出來但是不被接受</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>收款</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>收款自</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>付款</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>付給自己</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(不適用)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>交易狀態。把游標停在欄位上會顯示確認次數。</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>收到交易的日期和時間。</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>交易的種類。</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>要減掉或加進餘額的金額。</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>這星期</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>這個月</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>上個月</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>今年</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>指定範圍...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>收款</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>付款</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>給自己</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>開採所得</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其它</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>最小金額</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>複製位址</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>複製標記</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>複製金額</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>複製交易識別碼</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>編輯標記</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>顯示交易明細</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>已確認</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>種類</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>標記:</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>位址</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>識別碼</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>範圍:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>到</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>在任意的通訊埠聽候失敗。如果你希望這樣的話，可以設定 -listen=0.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>無效的 -proxy 位址: '%s'</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>正在載入位址資料...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>在 -onlynet 指定了不明的網路別: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>累積金額不足</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>正在載入區塊索引...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>正在載入錢包資料...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>沒辦法把預設位址寫進去</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>正在重新掃描...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>載入完成</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
</context>
</TS>